<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>CreateLibraryItem</name>
    <message>
        <location filename="../CreateLibraryItem.js" line="+49"/>
        <source>Reference Point</source>
        <translation>Referenční bod</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Save library item as...</source>
        <translation>Uložit položku knihovny jako...</translation>
    </message>
    <message>
        <location filename="../CreateLibraryItemInit.js" line="+2"/>
        <source>&amp;Create Library Item</source>
        <translation>&amp;Vytvořit položku knihovny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Create library item from selection</source>
        <translation>Vytvořit položku knihovny z výběru</translation>
    </message>
</context>
</TS>
